import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_dynamodb
import aws_cdk.aws_lambda
import aws_cdk.aws_s3
import aws_cdk.aws_s3_deployment
import aws_cdk.core
import aws_cdk.custom_resources

__jsii_assembly__ = jsii.JSIIAssembly.load("aws-cdk-dynamodb-seeder", "1.36.1", __name__[0:-6], "aws-cdk-dynamodb-seeder@1.36.1.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
